@@ -1,4 +1,5 @@
 import os
+import pathlib
 import subprocess
 
 
@@ -18,7 +19,9 @@ def tm_align( pdb_file_1,pdb_file_2):
 
 def tm_score( pdb_file_1,pdb_file_2):
     import os.path
+    print(pathlib.Path(__file__).pathlib.Path(__file__))
     if (os.path.exists(r'TMscore')) == False:
+
         os.system('g++ -O3 -ffast-math -lm -o TMscore TMscore.cpp')
     batcmd = './TMscore {file1} {file2}'.format(file1=pdb_file_1, file2=pdb_file_2)
     # result = subprocess.check_output(batcmd, shell=True)
